@@ -5,6 +5,15 @@
 #  \____|_| |_|\___|\___|_|\_\ |_|  \___/|_|    |_|_|_.__/| .__/|_| |_|\__, |
 #                                                         |_|          |___/ 
 #
+# Repository: https://github.com/benkasminbullock/check4libpng
+#
+# This file lives in ~/projects/check4libpng/lib and should be copied
+# from there.
+#
+# 0.03 2018-09-16
+#
+# - Use $Config{cc} to get the C compiler
+#
 # 0.02 2017-07-01
 #
 # - Remove "Template" stuff
@@ -25,10 +34,10 @@ use utf8;
 use FindBin '$Bin';
 use Carp;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-# This uses $Config{ldflags} and $Config{ccflags} when it tries to
-# compile a small program which links against libpng.
+# This uses $Config{cc}, $Config{ldflags} and $Config{ccflags} to try
+# to compile a small program which links against libpng.
 
 use Config qw/%Config/;
 
@@ -36,21 +45,26 @@ use Config qw/%Config/;
 # to point to your libpng library's location and the location of the
 # directory containing the file "png.h".
 
-my $png_lib_dir;
-my $png_include_dir;
+my $png_lib_dir; # = /usr/local/lib , etc.
+my $png_include_dir; # = /usr/local/include, etc.
 
 # The following variable switches on printing of non-error messages
 
+#my $verbose = 1;
 my $verbose;
 
+# Debugging messages
+
 sub msg
 {
-    my ($msg) = @_;
+    my (undef, $file, $line) = caller (0);
     if ($verbose) {
-	print __PACKAGE__ . ": " . $msg . ".\n";
+	printf ("%s:%d: @_.\n", $file, $line);
     }
 }
 
+# Find an executable program called $program in $ENV{PATH}.
+
 sub find_program
 {
     my ($program) = @_;
@@ -75,11 +89,29 @@ sub find_program
     return $found;
 }
 
+# Look for libpng. If found, return value is a hash ref containing
+# keys "libs" and "inc" for the library directory and the include file
+# directory of libpng. If not found, return value is the undefined
+# value.
+
 sub check_for_libpng
 {
-    ($verbose) = @_;
+    my (%options) = @_;
+    if ($options{verbose}) {
+	$verbose = 1;
+    }
+    if ($options{prefix}) {
+	$png_include_dir = "$options{prefix}/include";
+	if (! -d $png_include_dir) {
+	    die "$png_include_dir doesn't exist";
+	}
+	$png_lib_dir = "$options{prefix}/lib";
+	if (! -d $png_lib_dir) {
+	    die "$png_lib_dir doesn't exist";
+	}
+    }
 
-    msg ("Debugging messages in check_for_libpng are switched on");
+    msg ("Debugging messages in 'check_for_libpng' are switched on");
 
     # $inc is a flag for the C compiler to tell it where to find header
     # files.
@@ -88,38 +120,47 @@ sub check_for_libpng
     if ($png_include_dir) {
 	$inc = "-I $png_include_dir";
     }
+    if ($inc) {
+	msg ("\$inc is '$inc'");
+    }
 
     # $libs is a flag for the C compiler to tell it where to find library
     # files.
 
     my $libs = '-lpng -lz -lm';
     if ($png_lib_dir) {
-	$libs = "-L $png_lib_dir $libs";
+	$libs = "-L$png_lib_dir $libs";
     }
-    my $has_pkg_config = find_program ('pkg-config', $verbose);
-    if ($has_pkg_config) {
-	msg ('I found "pkg-config" in your PATH so I am going to use that to help with the compilation of the C part of this module.');
-	my $pkg_config_cflags = `pkg-config --cflags libpng`;
-	$pkg_config_cflags =~ s/\s+$//;
-	my $pkg_config_ldflags = `pkg-config --libs libpng`;
-	$pkg_config_ldflags =~ s/\s+$//;
-	if ($pkg_config_cflags) {
-	    msg ("Adding '$pkg_config_cflags' to C compiler flags from pkg-config");
-	    $inc = "$inc $pkg_config_cflags";
+    if ($options{prefix}) {
+	if ($verbose) {
+	    print "Overriding library and include directories with $options{prefix}.\n";
 	}
-	if ($pkg_config_ldflags) {
-	    msg ("Adding '$pkg_config_ldflags' to linker flags from pkg-config");
-	    $libs = "$pkg_config_ldflags $libs";
+    }
+    else {
+	my $has_pkg_config = find_program ('pkg-config', $verbose);
+	if ($has_pkg_config) {
+	    msg ('I found "pkg-config" in your PATH so I am going to use that to help with the compilation of the C part of this module.');
+	    my $pkg_config_cflags = `pkg-config --cflags libpng`;
+	    $pkg_config_cflags =~ s/\s+$//;
+	    my $pkg_config_ldflags = `pkg-config --libs libpng`;
+	    $pkg_config_ldflags =~ s/\s+$//;
+	    if ($pkg_config_cflags) {
+		msg ("Adding '$pkg_config_cflags' to C compiler flags from pkg-config");
+		$inc = $pkg_config_cflags;
+	    }
+	    if ($pkg_config_ldflags) {
+		msg ("Adding '$pkg_config_ldflags' to linker flags from pkg-config");
+		$libs = $pkg_config_ldflags;
+	    }
 	}
     }
-
     # A minimal C program to test compilation and running.
 
     my $test_c = <<'EOF';
 #include <stdlib.h>
 #include <stdio.h>
 #include "png.h"
-void failburger (const char * message)
+void fatal_error (const char * message)
 {
     fprintf (stderr, "%s.\n", message);
     exit (1);
@@ -131,19 +172,20 @@ int main ()
    png_infop info_ptr;
    FILE * file;
    png_uint_32 libpng_vn = png_access_version_number();
-   printf ("IMAGE-PNG LIBPNG VERSION: <<%s>>\n", png_get_libpng_ver (0));
+   printf ("%s:%d: IMAGE-PNG LIBPNG VERSION: <<%s>>\n",
+	   __FILE__, __LINE__, png_get_libpng_ver (0));
    /* Create a file because there are some CPAN testers who seem to have bogus libpngs. */
 /*   file = fopen ("temporary.png", "wb");
    if (! file) {
-       failburger ("cannot open file");
+       fatal_error ("cannot open file");
    }*/
    png_ptr = png_create_write_struct (PNG_LIBPNG_VER_STRING, 0, 0, 0);
    if (! png_ptr) {
-       failburger ("cannot create write struct");
+       fatal_error ("cannot create write struct");
    }
    info_ptr = png_create_info_struct (png_ptr);
    if (! png_ptr) {
-       failburger ("cannot create info struct");
+       fatal_error ("cannot create info struct");
    }
 //   png_init_io (png_ptr, file);
    return 0;
@@ -167,12 +209,20 @@ EOF
 	my $ldflags = $Config{ldflags};
 	#    my $ccflags;
 	my $ccflags = $Config{ccflags};
+	# The C compiler to use
+	my $cc = $Config{cc};
+	if (! $cc) {
+	    die "I cannot find a C compiler in your \%Config";
+	}
 	open my $output, ">", $c_file_name
             or die "Error opening file '$c_file_name' for writing: $!";
 	print $output $test_c;
 	close $output
             or die "Error closing file '$c_file_name': $!";
-	my $compile = "cc $ccflags $inc -o $exe_file_name $c_file_name $ldflags $libs";
+	if ($options{prefix}) {
+	    $libs .= " -Wl,--rpath -Wl,$png_lib_dir ";
+	}
+	my $compile = "$cc $inc $ccflags -o $exe_file_name $c_file_name $libs $ldflags ";
 	msg ("The compile command is '$compile'");
 	$compile_ok = (system ($compile) == 0);
 	if ($compile_ok) {
@@ -257,6 +307,10 @@ EOF
     my %vals;
     $vals{libs} = $libs;
     $vals{inc} = $inc;
+    if ($verbose) {
+	print "libs = $vals{libs}\n";
+	print "inc = $vals{inc}\n";
+    }	
     return \%vals;
 }
 
